@@ -34,7 +34,6 @@ module xtb_api_calculator
    use xtb_type_molecule
    use xtb_type_calculator
    use xtb_xtb_calculator
-   use xtb_main_setup, only : addSolvationModel
    implicit none
    private
 
@@ -57,6 +56,7 @@ contains
 
 function newCalculator_api() result(vcalc) &
       & bind(C, name="xtb_newCalculator")
+   !DEC$ ATTRIBUTES DLLEXPORT :: newCalculator_api
    type(VCalculator), pointer :: calc
    type(c_ptr) :: vcalc
 
@@ -70,6 +70,7 @@ end function newCalculator_api
 
 subroutine delCalculator_api(vcalc) &
       & bind(C, name="xtb_delCalculator")
+   !DEC$ ATTRIBUTES DLLEXPORT :: delCalculator_api
    type(c_ptr), intent(inout) :: vcalc
    type(VCalculator), pointer :: calc
 
@@ -86,6 +87,7 @@ end subroutine delCalculator_api
 
 subroutine loadGFNFF_api(venv, vmol, vcalc, charptr) &
       & bind(C, name="xtb_loadGFNFF")
+   !DEC$ ATTRIBUTES DLLEXPORT :: loadGFNFF_api
    character(len=*), parameter :: source = 'xtb_api_loadGFNFF'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -148,6 +150,7 @@ end subroutine loadGFNFF_api
 
 subroutine loadGFN0xTB_api(venv, vmol, vcalc, charptr) &
       & bind(C, name="xtb_loadGFN0xTB")
+   !DEC$ ATTRIBUTES DLLEXPORT :: loadGFN0xTB_api
    character(len=*), parameter :: source = 'xtb_api_loadGFN0xTB'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -210,6 +213,7 @@ end subroutine loadGFN0xTB_api
 
 subroutine loadGFN1xTB_api(venv, vmol, vcalc, charptr) &
       & bind(C, name="xtb_loadGFN1xTB")
+   !DEC$ ATTRIBUTES DLLEXPORT :: loadGFN1xTB_api
    character(len=*), parameter :: source = 'xtb_api_loadGFN1xTB'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -272,6 +276,7 @@ end subroutine loadGFN1xTB_api
 
 subroutine loadGFN2xTB_api(venv, vmol, vcalc, charptr) &
       & bind(C, name="xtb_loadGFN2xTB")
+   !DEC$ ATTRIBUTES DLLEXPORT :: loadGFN2xTB_api
    character(len=*), parameter :: source = 'xtb_api_loadGFN2xTB'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -335,6 +340,7 @@ end subroutine loadGFN2xTB_api
 !> Add a solvation model to calculator (requires loaded parametrisation)
 subroutine setSolvent_api(venv, vcalc, charptr, state, temperature, grid) &
       & bind(C, name="xtb_setSolvent")
+   !DEC$ ATTRIBUTES DLLEXPORT :: setSolvent_api
    character(len=*), parameter :: source = 'xtb_api_setSolvent'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -411,6 +417,7 @@ end subroutine setSolvent_api
 !> Unset the solvation model
 subroutine releaseSolvent_api(venv, vcalc) &
       & bind(C, name="xtb_releaseSolvent")
+   !DEC$ ATTRIBUTES DLLEXPORT :: releaseSolvent_api
    character(len=*), parameter :: source = 'xtb_api_setRelease'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -442,6 +449,7 @@ end subroutine releaseSolvent_api
 !> Add a external charge potential to calculator (only supported in GFN1/2-xTB)
 subroutine setExternalCharges_api(venv, vcalc, npc, numbers, charges, positions) &
       & bind(C, name="xtb_setExternalCharges")
+   !DEC$ ATTRIBUTES DLLEXPORT :: setExternalCharges_api
    character(len=*), parameter :: source = 'xtb_api_setExternalCharges'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -504,6 +512,7 @@ end subroutine setExternalCharges_api
 !> Unset the external charge potential
 subroutine releaseExternalCharges_api(venv, vcalc) &
       & bind(C, name="xtb_releaseExternalCharges")
+   !DEC$ ATTRIBUTES DLLEXPORT :: releaseExternalCharges_api
    character(len=*), parameter :: source = 'xtb_api_releaseExternalCharges'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -536,6 +545,7 @@ end subroutine releaseExternalCharges_api
 
 subroutine setAccuracy_api(venv, vcalc, accuracy) &
       & bind(C, name="xtb_setAccuracy")
+   !DEC$ ATTRIBUTES DLLEXPORT :: setAccuracy_api
    character(len=*), parameter :: source = 'xtb_api_setAccuracy'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -578,6 +588,7 @@ end subroutine setAccuracy_api
 
 subroutine setMaxIter_api(venv, vcalc, maxiter) &
       & bind(C, name="xtb_setMaxIter")
+   !DEC$ ATTRIBUTES DLLEXPORT :: setMaxIter_api
    character(len=*), parameter :: source = 'xtb_api_setMaxIter'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
@@ -616,6 +627,7 @@ end subroutine setMaxIter_api
 
 subroutine setElectronicTemp_api(venv, vcalc, temperature) &
       & bind(C, name="xtb_setElectronicTemp")
+   !DEC$ ATTRIBUTES DLLEXPORT :: setElectronicTemp_api
    character(len=*), parameter :: source = 'xtb_api_setElectronicTemp'
    type(c_ptr), value :: venv
    type(VEnvironment), pointer :: env
