@@ -102,20 +102,29 @@ module xtb_setparam
    integer,parameter :: p_pcem_orca = 2
    
    type oniom_settings
+      !> inner region charge
       integer  :: innerchrg
-         !! inner region charge
+      
+      !> cut high order(>1) covalent bonds
+      logical :: ignore_topo = .false.
+      
+      !> derived mode
       logical :: derived = .false.
-         !! set ONIOM optimization parameter g to derived value
+      
+      !> dummy execution to check inner region geo and chrg
       logical :: cut_inner = .false.
-         !! to execute xtb just for checking inner region cut
+
+      !> explicite charges (inner:outer)
       logical :: fixed_chrgs= .false.
-         !! if charges for oniom explicitely given
+      
+      !> mute external output (ORCA,TURBOMOLE)
       logical :: silent = .false.
-         !! zo mute external output
+      
+      !> print optimization logs for inner region calculations
       logical :: logs = .false.
-         !! if optimization logs of inner regions are needed
+      
+      !> log units
       integer:: ilog1, ilog2
-         !! log units
   end type oniom_settings
 
    type qm_external
@@ -324,6 +333,8 @@ module xtb_setparam
    real(wp) :: cube_step = 0.4_wp
 !  density matrix neglect threshold
    real(wp) :: cube_pthr = 0.05_wp
+!  cube boundary offset
+   real(wp) :: cube_boff = 3.0_wp
 !! ------------------------------------------------------------------------
 !  PRINTOUT
 !! ------------------------------------------------------------------------
@@ -427,6 +438,7 @@ module xtb_setparam
 !  information about molecule
 !! ------------------------------------------------------------------------
    integer  :: ichrg = 0
+   logical  :: clichrg = .false.
    integer  :: nalphabeta = 0
 
 !  cannot be set by .xtbrc/setblock
